==> minitube_0.9.orig.tar.gz: minitube/locale/tr_TR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Tarayıcının dışındaki yaşam!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Bu &quot;Teknoloji gösterimi&quot; sürümüdür, mükemmel olmasını beklemeyin.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Hataları ve yeni fikirlerinizi  %1 adresine gönderin.</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 özgür yazılımdır ama geliştirmek değerli zaman alır.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Lütfen %2 gelişiminin sürekliliği için &lt;a href=&apos;%1&apos;&gt;PayPal ile bağış&lt;/a&gt; yaparak destek olun.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Simge %1 tarafından tasarlandı.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Pencereye sığdırmada %1&apos;ün katkısı var.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP Vekil desteğinde %1&apos;nin katkısı var.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows sürümü %1 tarafından yapıldı.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Çevirenler %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU Genel Kamu Lisansı&lt;/a&gt; ile yayınlanmıştır.</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Aranıyor...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>%1 Tane daha</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Video yok</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Daha fazla yok</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Geri</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Öncekine git</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Dur</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Oynatmayı durdur ve aramaya geri dön</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Atla</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Sonraki videoya atla</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Bekle</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Oynatmayı beklet</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tam ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Tam ekran görünümü</translation>
    </message>
    <message>
        <source>&amp;Compact View</source>
        <translation type="obsolete">&amp;Kompakt Ansicht</translation>
    </message>
    <message>
        <source>Go compact view</source>
        <translation type="obsolete">Kompakt Ansicht aktivieren</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>YouTube video sayfasını aç</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Pencereye sığdır</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Listeyi ve araç çubuğunu gizle</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation type="obsolete">&amp;Herunterladen</translation>
    </message>
    <message>
        <source>Download this video</source>
        <translation type="obsolete">Dieses Video herunterladen</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="obsolete">Strg+S</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Kaldır</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Seçilen videoları listeden kaldır</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Y&amp;ukarı taşı</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Seçilen videoları listede yukarı taşı</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>A&amp;şağı taşı</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Seçilen videoları listede aşağı taşı</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Ç</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Gülegüle</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Website</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 İnternette</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>PayPal ile ba&amp;ğış yap</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Lütfen %1 gelişiminin sürekliliği için destekleyin</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1 Hakkında</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Sesi kes</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 Sesi arttır, %2 sesi azalt</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Kalan zaman: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Yüksek çözünürlüklü video aktif</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Yüksek çözünürlüklü video aktif değil</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>Geçerli video yüksek çözünürlüklü</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>Geçerli video yüksek çözünürlüklü değil</translation>
    </message>
    <message>
        <source>No Video playing</source>
        <translation type="obsolete">Es wird kein Video abgespielt</translation>
    </message>
    <message>
        <source>You must first play the video you intent to download !</source>
        <translation type="obsolete">Du musst das Video erst abspielen !</translation>
    </message>
    <message>
        <source>Save video as...</source>
        <translation type="obsolete">Video speichern unter...</translation>
    </message>
    <message>
        <source>minitube video.mp4</source>
        <translation type="obsolete">minitube video.mp4</translation>
    </message>
    <message>
        <source>Downloading: </source>
        <translation type="obsolete">Herunterladen:</translation>
    </message>
    <message>
        <source>Abort Download</source>
        <translation type="obsolete">Herunterladen abbrechen</translation>
    </message>
    <message>
        <source>File creation failed</source>
        <translation type="obsolete">Das anlegen der Datei ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Download failed</source>
        <translation type="obsolete">Herunterladen fehlgeschlagen</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Ses %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ses kapandı</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ses açık</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Suche</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Uygulama</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Oynatma &amp;listesi</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Yardı&amp;m</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 Açılıyor</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>İç hata: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hata: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Oynat</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Oynatmaya devam et</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>&amp;Tam ekrandan çık</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Geçmiş aramaları &amp;sil</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>En ilgili</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>En yeni</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Çok izlenen</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>&quot;%1&quot; İzliyorsunuz</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Ağ hatası: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 görüntüleme</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;a Hoşgeldiniz</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Bir anahtar kelime girerek izlemeye başlayın.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>İzle</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Son arananlar</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>%1&apos;un yeni sürümü mevcut. Lütfen buradan &lt;a href=&apos;%2&apos;&gt; %3 sürümüne yükseltin&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Kendinize konfor sunun</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">S&amp;chließen</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Ağ hatası: %2 için  %1</translation>
    </message>
</context>
</TS>

==> minitube_1.1.orig.tar.gz: minitube/locale/tr_TR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Tarayıcının dışındaki yaşam!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Bu &quot;Teknoloji gösterimi&quot; sürümüdür, mükemmel olmasını beklemeyin.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Hataları ve yeni fikirlerinizi  %1 adresine gönderin</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 özgür yazılımdır ama geliştirmek değerli zaman alır.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">Lütfen %2 gelişiminin sürekliliği için &lt;a href=&apos;%1&apos;&gt;PayPal ile bağış&lt;/a&gt; yaparak destek olun.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Simge %1 tarafından tasarlandı.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Pencereye sığdırmada %1&apos;ün katkısı var.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP Vekil desteğinde %1&apos;nin katkısı var.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows sürümü %1 tarafından yapıldı.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Çevirenler %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;GNU Genel Kamu Lisansı&lt;/a&gt; ile yayınlanmıştır</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation></translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Lütfen %2 geliştirilmesinin devam etmesi için &lt;a href=&apos;%1&apos;&gt;bağış&lt;/a&gt; yapın.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Aranıyor...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>%1 Tane daha</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Video yok</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Daha fazla yok</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Geri</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Öncekine git</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Dur</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Oynatmayı durdur ve aramaya geri dön</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Atla</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Sonraki videoya atla</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Bekle</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Oynatmayı beklet</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tam ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Tam ekran görünümü</translation>
    </message>
    <message>
        <source>&amp;Compact View</source>
        <translation type="obsolete">&amp;Kompakt Ansicht</translation>
    </message>
    <message>
        <source>Go compact view</source>
        <translation type="obsolete">Kompakt Ansicht aktivieren</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">YouTube video sayfasını aç</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation type="obsolete">Ctrl+Y</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Pencereye sığdır</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Listeyi ve araç çubuğunu gizle</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation type="obsolete">&amp;Herunterladen</translation>
    </message>
    <message>
        <source>Download this video</source>
        <translation type="obsolete">Dieses Video herunterladen</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="obsolete">Strg+S</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Kaldır</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Seçilen videoları listeden kaldır</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Y&amp;ukarı taşı</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Seçilen videoları listede yukarı taşı</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>A&amp;şağı taşı</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Seçilen videoları listede aşağı taşı</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çık</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Ç</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Gülegüle</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Website</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 İnternette</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">PayPal ile ba&amp;ğış yap</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Lütfen %1 gelişiminin sürekliliği için destekleyin</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>%1 Hakkında</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Sesi kes</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>%1 Sesi arttır, %2 sesi azalt</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Kalan zaman: %1</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">Yüksek çözünürlüklü video aktif</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">Yüksek çözünürlüklü video aktif değil</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Geçerli video yüksek çözünürlüklü</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Geçerli video yüksek çözünürlüklü değil</translation>
    </message>
    <message>
        <source>No Video playing</source>
        <translation type="obsolete">Es wird kein Video abgespielt</translation>
    </message>
    <message>
        <source>You must first play the video you intent to download !</source>
        <translation type="obsolete">Du musst das Video erst abspielen !</translation>
    </message>
    <message>
        <source>Save video as...</source>
        <translation type="obsolete">Video speichern unter...</translation>
    </message>
    <message>
        <source>minitube video.mp4</source>
        <translation type="obsolete">minitube video.mp4</translation>
    </message>
    <message>
        <source>Downloading: </source>
        <translation type="obsolete">Herunterladen:</translation>
    </message>
    <message>
        <source>Abort Download</source>
        <translation type="obsolete">Herunterladen abbrechen</translation>
    </message>
    <message>
        <source>File creation failed</source>
        <translation type="obsolete">Das anlegen der Datei ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Download failed</source>
        <translation type="obsolete">Herunterladen fehlgeschlagen</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Ses %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ses kapandı</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ses açık</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Suche</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Uygulama</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Oynatma &amp;listesi</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Yardı&amp;m</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 Açılıyor</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>İç hata: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hata: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Oynat</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Oynatmaya devam et</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>&amp;Tam ekrandan çık</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>Geçmiş aramaları &amp;sil</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Arama geçmişini sil. Bu geri alınamaz.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Şimdi gizliliğiniz güvende</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>&amp;YouTube sayfasını aç</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Oynatmayı beklet ve YouTube sayfasına git</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>YouTube bağlantısını &amp;kopyala</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Geçerli videonun YouTube bağlantısını panoya kopyala</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Video akışı &amp;URL adresini kopyala</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Geçerli video akışının URL adresini panoya kopyala</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>&amp;Bağış yap</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>En yüksek video tanımı %1 olarak ayarlı</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>En ilgili</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>En yeni</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Çok izlenen</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>&quot;%1&quot; İzliyorsunuz</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Şimdi YouTube bağlantısını başka bir uygulamaya yapıştırabilirsiniz</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Şimdi video akışı URL adresini başka bir uygulamaya yapıştırabilirsiniz</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Bağlantı kısıtlı bir süre için geçerli olacak.</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Ağ hatası: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 görüntüleme</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;&apos;a Hoşgeldiniz</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Bir anahtar kelime girerek izlemeye başlayın.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>İzle</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Son arananlar</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>%1&apos;un yeni sürümü mevcut. Lütfen buradan &lt;a href=&apos;%2&apos;&gt; %3 sürümüne yükseltin&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Kendinize konfor sunun</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Seçenekler</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">S&amp;chließen</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Ağ hatası: %2 için  %1</translation>
    </message>
</context>
</TS>
